@@ -87,6 +87,8 @@ FrMimeTypeDescription mime_type_desc[] = {
 	{ "application/x-lha",                  ".lzh",      0 },
 	{ "application/x-lrzip",                ".lrz",      0 },
 	{ "application/x-lrzip-compressed-tar", ".tar.lrz",  0 },
+	{ "application/x-lz4",                  ".lz4",      0 },
+	{ "application/x-lz4-compressed-tar",   ".tar.lz4",  0 },
 	{ "application/x-lzip",                 ".lz",       0 },
 	{ "application/x-lzip-compressed-tar",  ".tar.lz",   0 },
 	{ "application/x-lzma",                 ".lzma",     0 },
@@ -134,6 +136,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".lrz", "application/x-lrzip" },
 	{ ".lzh", "application/x-lha" },
 	{ ".lz", "application/x-lzip" },
+	{ ".lz4", "application/x-lz4" },
 	{ ".lzma", "application/x-lzma" },
 	{ ".lzo", "application/x-lzop" },
 	{ ".rar", "application/x-rar" },
@@ -147,6 +150,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".tar.gz", "application/x-compressed-tar" },
 	{ ".tar.lrz", "application/x-lrzip-compressed-tar" },
 	{ ".tar.lz", "application/x-lzip-compressed-tar" },
+	{ ".tar.lz4", "application/x-lz4-compressed-tar" },
 	{ ".tar.lzma", "application/x-lzma-compressed-tar" },
 	{ ".tar.lzo", "application/x-lzop-compressed-tar" },
 	{ ".tar.7z", "application/x-7z-compressed-tar" },
@@ -159,6 +163,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".tgz", "application/x-compressed-tar" },
 	{ ".txz", "application/x-xz-compressed-tar" },
 	{ ".tlz", "application/x-lzip-compressed-tar" },
+	{ ".tlz4", "application/x-lz4-compressed-tar" },
 	{ ".tzma", "application/x-lzma-compressed-tar" },
 	{ ".tzo", "application/x-lzop-compressed-tar" },
 	{ ".war", "application/x-war" },
